@@ -1,5 +1,15 @@
-#' Render Diagram
+stop_if_no_phantomjs <- function() {
+  if (!webshot::is_phantomjs_installed()) {
+    stop("You must install phantomjs using webshot::install_phantomjs()")
+  }
+}
+
+#' Render nomnoml diagram.
 #'
+#' @description 
+#' 
+#' `r lifecycle::badge("experimental")`
+#' 
 #' Renders a 'nomnoml' diagram as an 'htmlwidget' or saves it
 #' as a 'png' image.
 #' 
@@ -11,207 +21,29 @@
 #'   'svg' is not at a par with 'png' and renders incorrectly at times.
 #' @param ... Additional parameters.
 #' 
+#' 
 #' @details
 #' 
 #' The 'nomnoml' syntax is simple and intuitive, a "Hello World"
 #' example can be rendered as an 'htmlwidget' as follows:
 #' 
-#' \code{nomnoml::nomnoml("[Hello]-[World!]", "orange")}
+#' `nomnoml::nomnoml("[Hello]-[World!]")`
 #' 
 #' You can also render as a 'png' file with specific dimensions:
 #' 
-#' \code{nomnoml::nomnoml("[Hello]-[World!]", "hello.png", 600, 100)}
+#' `nomnoml::nomnoml("[Hello]-[World!]", png = "hello.png", 600, 100)`
 #' 
 #' Still, complex diagrams can be defined by combining multiple
 #' association types, classifier types, directives and
 #' custom classifier styles.
 #' 
-#' You can also use of the \code{nomnoml} 'knitr' chunk
+#' You can also use of the `nomnoml` 'knitr' chunk
 #' to render inline diagrams in R Markdown documents.
 #' 
-#' @section Association Types:
+#' @section Syntax:
 #' 
-#' \code{association -}
-#' 
-#' \code{association ->}
-#' 
-#' \code{association <->}
-#' 
-#' \code{dependency -->}
-#' 
-#' \code{dependency <-->}
-#' 
-#' \code{generalization -:>}
-#' 
-#' \code{generalization <:-}
-#' 
-#' \code{implementation --:>}
-#' 
-#' \code{implementation <:--}
-#' 
-#' \code{composition +-}
-#' 
-#' \code{composition +->}
-#' 
-#' \code{aggregation o-}
-#' 
-#' \code{aggregation o->}
-#' 
-#' \code{note --}
-#' 
-#' \code{hidden -/-}
-#' 
-#' @section Classifier Types:
-#' 
-#' \code{[name]}
-#' 
-#' \code{[<abstract> name]}
-#' 
-#' \code{[<instance> name]}
-#' 
-#' \code{[<note> name]}
-#' 
-#' \code{[<reference> name]}
-#' 
-#' \code{[<package> name]}
-#' 
-#' \code{[<frame> name]}
-#' 
-#' \code{[<database> name]}
-#' 
-#' \code{[<start> name]}
-#' 
-#' \code{[<end> name]}
-#' 
-#' \code{[<state> name]}
-#' 
-#' \code{[<choice> name]}
-#' 
-#' \code{[<input> name]}
-#' 
-#' \code{[<sender> name]}
-#' 
-#' \code{[<receiver> name]}
-#' 
-#' \code{[<transceiver> name]}
-#' 
-#' \code{[<actor> name]}
-#' 
-#' \code{[<usecase> name]}
-#' 
-#' \code{[<label> name]}
-#' 
-#' \code{[<hidden> name]}
-#' 
-#' @section Directives:
-#' 
-#' \code{#arrowSize: 1}
-#' 
-#' \code{#bendSize: 0.3}
-#' 
-#' \code{#direction: down | right}
-#' 
-#' \code{#gutter: 5}
-#' 
-#' \code{#edgeMargin: 0}
-#' 
-#' \code{#edges: hard | rounded}
-#' 
-#' \code{#fill: #eee8d5; #fdf6e3}
-#' 
-#' \code{#fillArrows: false}
-#' 
-#' \code{#font: Calibri}
-#' 
-#' \code{#fontSize: 12}
-#' 
-#' \code{#leading: 1.25}
-#' 
-#' \code{#lineWidth: 3}
-#' 
-#' \code{#padding: 8}
-#' 
-#' \code{#spacing: 40}
-#' 
-#' \code{#stroke: #33322E}
-#' 
-#' \code{#title: filename}
-#' 
-#' \code{#zoom: 1}
-#' 
-#' @section Custom Classifier Styles:
-#' 
-#' A directive that starts with \code{.} define a classifier style.
-#' The style is written as a space separated list of modifiers and
-#' key/value pairs.
-#' 
-#' \code{#.box: fill=#8f8 dashed}
-#' 
-#' \code{#.blob: visual=ellipse}
-#' 
-#' \code{[<box> GreenBox]}
-#' 
-#' \code{[<blob> HideousBlob]}
-#' 
-#' Available key/value pairs are:
-#' 
-#' \code{fill=(any css color)}
-#' 
-#' \code{stroke=(any css color)}
-#' 
-#' \code{align=center}
-#' 
-#' \code{align=left}
-#' 
-#' \code{direction=right}
-#' 
-#' \code{direction=down}
-#' 
-#' \code{visual=actor}
-#' 
-#' \code{visual=class}
-#' 
-#' \code{visual=database}
-#' 
-#' \code{visual=ellipse}
-#' 
-#' \code{visual=end}
-#' 
-#' \code{visual=frame}
-#' 
-#' \code{visual=hidden}
-#' 
-#' \code{visual=input}
-#' 
-#' \code{visual=none}
-#' 
-#' \code{visual=note}
-#' 
-#' \code{visual=package}
-#' 
-#' \code{visual=receiver}
-#' 
-#' \code{visual=rhomb}
-#' 
-#' \code{visual=roundrect}
-#' 
-#' \code{visual=sender}
-#' 
-#' \code{visual=start}
-#' 
-#' \code{visual=transceiver}
-#' 
-#' Available modifiers are:
-#' 
-#' \code{bold}
-#' 
-#' \code{underline}
-#' 
-#' \code{italic}
-#' 
-#' \code{dashed}
-#' 
-#' \code{empty}
+#' For a summary of available `nomnoml` syntax, including association types, 
+#' directives and customer classifier styles, see [nomnoml_syntax]
 #' 
 #' @examples 
 #' # Render simple diagram:
@@ -230,6 +62,9 @@
 #'   ]")
 #'
 #' @import htmlwidgets
+#' 
+#' @seealso [nomnomlOutput()], [renderNomnoml()], [nomnoml_validate()]
+#' 
 #' @export
 nomnoml <- function(
   code = "[Hello]-[World!]",
@@ -239,6 +74,7 @@ nomnoml <- function(
   svg = FALSE,
   ...) {
   
+  
   # forward options using x
   x <- list(
     code = paste(
@@ -259,6 +95,10 @@ nomnoml <- function(
   )
   
   if (!is.null(png)) {
+    if (svg) stop("Parameter 'svg' must be false when creating PNGs.")
+    
+    stop_if_no_phantomjs()
+    
     file <- tempfile(fileext = ".html")
     htmlwidgets::saveWidget(widget, file)
     
@@ -269,21 +109,27 @@ nomnoml <- function(
   }
 }
 
-#' Shiny bindings for nomnoml
+#' Shiny bindings for nomnoml.
+#' 
+#' @description 
+#' 
+#' `r lifecycle::badge("experimental")`
 #'
 #' Output and render functions for using nomnoml within Shiny
 #' applications and interactive Rmd documents.
 #'
 #' @param outputId output variable to read from
-#' @param width,height Must be a valid CSS unit (like \code{'100\%'},
-#'   \code{'400px'}, \code{'auto'}) or a number, which will be coerced to a
-#'   string and have \code{'px'} appended.
+#' @param width,height Must be a valid CSS unit (like `'100%'`,
+#'   `'400px'`, `'auto'`) or a number, which will be coerced to a
+#'   string and have `'px'` appended.
 #' @param expr An expression that generates a nomnoml
-#' @param env The environment in which to evaluate \code{expr}.
-#' @param quoted Is \code{expr} a quoted expression (with \code{quote()})? This
+#' @param env The environment in which to evaluate `expr`.
+#' @param quoted Is `expr` a quoted expression (with `quote()`)? This
 #'   is useful if you want to save an expression in a variable.
 #'
 #' @name nomnoml-shiny
+#' 
+#' @seealso [nomnoml()]
 #'
 #' @export
 nomnomlOutput <- function(outputId, width = '100%', height = '400px'){
